@@ -20,7 +20,9 @@ class ScenarioGenerator():
 
             parameters (dict of lists, or list of dicts): parameter sets to be used
 
-            naming (str): two options
+            naming (str): two options "numerical" or "parameter"
+
+            generate_all_roads (bool): will only generate unique roads 
     """
     def __init__(self):
         self.road_file = ''
@@ -28,7 +30,9 @@ class ScenarioGenerator():
         self.naming = 'numerical' # can be 'numerical', 'parameter'
         self._it = 0
         self._generation_folder = ''
-        self._write_relative_road_path = False
+        self.write_relative_road_path = False
+        self.generate_all_roads = True
+        self._created_roads = {}
     def road(self,**kwargs):
         """ Dummy method for generating an OpenDRIVE road
 
@@ -101,9 +105,6 @@ class ScenarioGenerator():
 
         elif isinstance(self.parameters,list):
             self.all_permutations = self.parameters
-
-  
-        
     
     def _generate_road_and_scenario(self,permutation):
         """ _generate_road_and_scenario takes a permutation and generates the road/scenario (if specified)
@@ -122,11 +123,21 @@ class ScenarioGenerator():
 
         road = self.road(**permutation)
         if road:
-            self.road_file = os.path.abspath(os.path.join(self._generation_folder,'xodr',scenario_name+'.xodr'))
-            road.write_xml(self.road_file)
-            if self.write_relative_road_path:
-                self.road_file = self.road_file.replace(os.path.abspath(self._generation_folder),os.path.pardir)
+            new_unique_road = True
+            if not self.generate_all_roads:
+                for previous_road in self._created_roads:
+                    if self._created_roads[previous_road] == road:
+                        self.road_file = previous_road
+                        new_unique_road = False
+            
+                
+            if new_unique_road:
+                self.road_file = os.path.abspath(os.path.join(self._generation_folder,'xodr',scenario_name+'.xodr'))
+                road.write_xml(self.road_file)
+                if self.write_relative_road_path:
+                    self.road_file = self.road_file.replace(os.path.abspath(self._generation_folder),os.path.pardir)
 
+                self._created_roads[self.road_file] = road
 
         sce = self.scenario(**permutation)
         if sce:
@@ -159,10 +170,25 @@ class ScenarioGenerator():
         return os.path.basename(sys.modules[self.__class__.__module__].__file__).split('.')[0]+name_prefix
 
 
-    def generate_single(self,generation_folder, order = 'first',override_parameters = None, write_relative_road_path = False):
+    def generate_single(self,generation_folder, order = 'first',override_parameters = None, write_relative_road_path = True):
         """ generate_single will generate only one scenario
 
+            Parameters
+            ----------
+                generation_folder (str): the path to a folder where the files should be generated
 
+                order (str, or int): if multiple permutations are defined, this enables the picking of different permutations
+                                     int - the number of that permutation
+                                     str - first: first permutation
+                                           middle: the permutation in the middle
+                                           random: a random permutation
+                    Default: 'first'
+
+                override_parameters (list of dicts, or dict of lists): overrides the self.parameters attribute (optional)
+
+                write_relative_road_path (bool): if the generator will write the path to a generated xodr file relative to the xosc (true), 
+                                                 or the absolute path to the xodr (false)
+                    Default: True
         """
         self.write_relative_road_path = write_relative_road_path
         self._create_folder_structure(generation_folder)
@@ -183,7 +209,7 @@ class ScenarioGenerator():
         return self._generate_road_and_scenario(self.all_permutations[it])
 
 
-    def generate(self,generation_folder,override_parameters = None, write_relative_road_path = False):
+    def generate(self,generation_folder,override_parameters = None, write_relative_road_path = True):
         """ generate uses the xosc.Scenario defined in the method scenario and the xodr.OpenDrive (optional) in the road method
             together with the parameters attribute to generate scenarios and roads for all permutations defined and save those files
             in the generation_folder.
@@ -192,7 +218,10 @@ class ScenarioGenerator():
             ----------
                 generation_folder (str): the path to a folder where the files should be generated
                 
-                override_parameters (list of dicts, or dict of lists): overrides the self.parameters attribute
+                override_parameters (list of dicts, or dict of lists): overrides the self.parameters attribute (optional)
+
+                write_relative_road_path (bool): if the generator will write the path to a generated xodr file relative to the xosc (true), or the absolute path to the xodr (false)
+                    Default: True
         """
         self.write_relative_road_path = write_relative_road_path
         scenario_files = []
