@@ -1,4 +1,6 @@
+""" Some custom exceptions
 
+"""
 
 
 class NotSameAmountOfLanesError(Exception):
@@ -24,4 +26,9 @@ class UndefinedRoadNetwork(Exception):
 class RoadsAndLanesNotAdjusted(Exception):
     """ Raised when the user tries to perform an action on non-adjusted lanes and roads that requires adjusted lanes and roads
     """
+    pass
+
+class MixOfGeometryAddition(Exception):
+    """ Raise when the wrong way of adding geometires are used for the planview
+    """
     pass
\ No newline at end of file
