@@ -34,7 +34,7 @@ def printToFile(element,filename,prettyprint=True):
     if prettyprint:    
         rough = ET.tostring(element,'utf-8').replace(b'\n',b'').replace(b'\t',b'')
         reparsed = mini.parseString(rough)
-        towrite = reparsed.toprettyxml(indent="\t")
+        towrite = reparsed.toprettyxml(indent="    ")
         with open(filename,'w') as file_handle:
             file_handle.write(towrite)
     else:
